@@ -15,7 +15,7 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
-from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
+from .utils import SKIP_IN_PATH, NamespacedClient, _make_path, query_params
 
 
 class RollupClient(NamespacedClient):
@@ -24,7 +24,7 @@ class RollupClient(NamespacedClient):
         """
         Deletes an existing rollup job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/rollup-delete-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/rollup-delete-job.html>`_
 
         .. warning::
 
@@ -45,7 +45,7 @@ class RollupClient(NamespacedClient):
         """
         Retrieves the configuration, stats, and status of rollup jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/rollup-get-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/rollup-get-job.html>`_
 
         .. warning::
 
@@ -65,7 +65,7 @@ class RollupClient(NamespacedClient):
         Returns the capabilities of any rollup jobs that have been configured for a
         specific index or index pattern.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/rollup-get-rollup-caps.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/rollup-get-rollup-caps.html>`_
 
         .. warning::
 
@@ -85,7 +85,7 @@ class RollupClient(NamespacedClient):
         Returns the rollup capabilities of all jobs inside of a rollup index (e.g. the
         index where rollup data is stored).
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/rollup-get-rollup-index-caps.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/rollup-get-rollup-index-caps.html>`_
 
         .. warning::
 
@@ -107,7 +107,7 @@ class RollupClient(NamespacedClient):
         """
         Creates a rollup job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/rollup-put-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/rollup-put-job.html>`_
 
         .. warning::
 
@@ -136,7 +136,7 @@ class RollupClient(NamespacedClient):
         """
         Enables searching rolled-up data using the standard query DSL.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/rollup-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/rollup-search.html>`_
 
         .. warning::
 
@@ -169,7 +169,7 @@ class RollupClient(NamespacedClient):
         """
         Starts an existing, stopped rollup job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/rollup-start-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/rollup-start-job.html>`_
 
         .. warning::
 
@@ -193,7 +193,7 @@ class RollupClient(NamespacedClient):
         """
         Stops an existing, started rollup job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/rollup-stop-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/rollup-stop-job.html>`_
 
         .. warning::
 
@@ -222,7 +222,12 @@ class RollupClient(NamespacedClient):
         """
         Rollup an index
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/rollup-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/xpack-rollup.html>`_
+
+        .. warning::
+
+            This API is **experimental** so may include breaking changes
+            or be removed in a future version
 
         :arg index: The index to roll up
         :arg rollup_index: The name of the rollup index to create
